scoretools.Performer
====================

.. inheritance-diagram:: abjad.tools.scoretools.Performer.Performer.Performer
   :private-bases:

.. autoclass:: abjad.tools.scoretools.Performer.Performer.Performer

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.instrument_count

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.is_doubling

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.likely_instruments_based_on_performer_name

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.most_likely_instrument_based_on_performer_name

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.instruments

.. autoattribute:: abjad.tools.scoretools.Performer.Performer.Performer.name

Methods
-------

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.make_performer_name_instrument_dictionary

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__eq__

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__hash__

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__ne__

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.scoretools.Performer.Performer.Performer.__str__

   .. note:: Inherited from `__builtin__.object`
